/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file FiltersVisibilityMap.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_FILTERSVISIBILITYMAP_H
#define GMIC_QT_FILTERSVISIBILITYMAP_H

#include <QSet>

class FiltersVisibilityMap {
public:
  static bool filterIsVisible(const QString & hash);
  static void setVisibility(const QString & hash, bool visible);
  static void load();
  static void save();

protected:
private:
  static QSet<QString> _hiddenFilters;
  FiltersVisibilityMap() = delete;
};

#endif // GMIC_QT_FILTERSVISIBILITYMAP_H
